@@ -8,13 +8,17 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_ecr._jsii
+import aws_cdk.aws_ecr_assets._jsii
+import aws_cdk.aws_iam._jsii
 import aws_cdk.core._jsii
+import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-apprunner",
-    "1.118.0",
+    "1.154.0",
     __name__[0:-6],
-    "aws-apprunner@1.118.0.jsii.tgz",
+    "aws-apprunner@1.154.0.jsii.tgz",
 )
 
 __all__ = [
